==> ukui-control-center_3.20.0.2022.0601.orig.tar.gz: ukui-control-center-3.20.0.2022.0601/plugins/time-language/area/languageframe.cpp <==
#include "languageframe.h"
#include <QHBoxLayout>
#include <QMenu>
#include <QProcess>
#include <QDebug>
#include <QTextCodec>

LanguageFrame::LanguageFrame(QString showName, QWidget *parent)
    :QFrame(parent)
{
    QHBoxLayout *layout = new QHBoxLayout(this);
    this->setFixedHeight(60);
    this->setFrameShape(QFrame::Box);
    this->setMinimumWidth(550);
    layout->setContentsMargins(16,0,16,0);

    nameLabel = new QLabel();
    nameLabel->setFixedWidth(200);
    nameLabel->setText(showName);

    selectedIconLabel = new QLabel();
    QFrame *frame = new QFrame(this);
    frame->setFixedSize(16,16);
    QHBoxLayout *frameLayout = new QHBoxLayout(this);
    frameLayout->setMargin(0);
    frame->setLayout(frameLayout);
    QIcon selectIcon = QIcon::fromTheme("ukui-selected");
    selectedIconLabel->setPixmap(selectIcon.pixmap(selectIcon.actualSize(QSize(16, 16))));
    const QByteArray id(THEME_QT_SCHEMA);
    QGSettings *mQtSettings = new QGSettings(id, QByteArray(), this);
    connect(mQtSettings, &QGSettings::changed, this, [=](QString key) {
        if (key == "iconThemeName")
            selectedIconLabel->setPixmap(selectIcon.pixmap(selectIcon.actualSize(QSize(16, 16))));
    });
    selectedIconLabel->setVisible(false);

    layout->addWidget(nameLabel);
    layout->addStretch();
    layout->addWidget(createToolBtn());
    frameLayout->addWidget(selectedIconLabel);
    layout->addWidget(frame);
    this->setObjectName(LANGUAGE_FRAME_OBJECT_NAME);
}

LanguageFrame::~LanguageFrame()
{

}

void LanguageFrame::mousePressEvent(QMouseEvent *e)
{
    if (!isSelection()) {
        this->showSelectedIcon(true);
        Q_EMIT clicked();
    }
    return;
}

void LanguageFrame::showSelectedIcon(bool flag)
{
    selectedIconLabel->setVisible(flag);
}

bool LanguageFrame::isSelection()
{
    return selectedIconLabel->isVisible();
}

QToolButton* LanguageFrame::createToolBtn()
{
    QToolButton *btn = new QToolButton(this);
    btn->setAutoRaise(true);
    btn->setPopupMode(QToolButton::InstantPopup);
    QMenu *menu = new QMenu(btn);
    btn->setMenu(menu);
    QAction *edit = new QAction(btn);
    QAction *del = new QAction(btn);
    edit->setText(tr("Input Settings"));
    del->setText(tr("Delete"));
    menu->addAction(edit);
    menu->addAction(del);

    connect(menu, &QMenu::aboutToShow, [=](){
        if (selectedIconLabel->isVisible()) {
            del->setEnabled(false);
        } else {
            del->setEnabled(true);
        }
    });

    connect(del, &QAction::triggered, this, [=](){
        if (hline) {
            hline->deleteLater();
            hline = nullptr;
        }
        Q_EMIT deleted();
        this->deleteLater();
    });

    connect(edit, &QAction::triggered, this, [=](){
        QProcess process;
        process.startDetached("fcitx-config-gtk3");

    });

    btn->setIcon(QIcon::fromTheme("view-more-horizontal-symbolic"));
    btn->setProperty("useButtonPalette", true);
    btn->setFixedSize(36,36);
    return btn;
}

void LanguageFrame::setHLine(HLineFrame *hline)
{
    this->hline = hline;
}

QString LanguageFrame::getShowName()
{
    return this->nameLabel->text();
}

==> ukui-control-center_3.22.1.25.orig.tar.gz: ukui-control-center-3.22.1.25/plugins/time-language/area/languageframe.cpp <==
#include "languageframe.h"
#include <QHBoxLayout>
#include <QMenu>
#include <QProcess>
#include <QDebug>
#include <QTextCodec>
#include "common.h"

LanguageFrame::LanguageFrame(QString showName, QWidget *parent)
    :UkccFrame(parent, BorderRadiusStyle::Top, true)
{
    QHBoxLayout *layout = new QHBoxLayout(this);
    layout->setContentsMargins(16, 0, 16, 0);

    nameLabel = new QLabel();
    nameLabel->setText(showName);

    selectedIconLabel = new QLabel();
    QFrame *frame = new QFrame(this);
    frame->setFixedSize(16, 16);
    QHBoxLayout *frameLayout = new QHBoxLayout(this);
    frameLayout->setMargin(0);
    frame->setLayout(frameLayout);
    selectIcon = QIcon::fromTheme("ukui-selected");
    selectedIconLabel->setPixmap(selectIcon.pixmap(selectIcon.actualSize(QSize(16, 16))));
    selectedIconLabel->setVisible(false);

    layout->addWidget(nameLabel);
    layout->addStretch();
    layout->addWidget(createToolBtn());
    frameLayout->addWidget(selectedIconLabel);
    layout->addWidget(frame);
    this->setObjectName("LanguageFrame");
}

LanguageFrame::~LanguageFrame()
{

}

void LanguageFrame::mousePressEvent(QMouseEvent *e)
{
    if (!isSelection()) {
        this->showSelectedIcon(true);
        Q_EMIT clicked();
    }
    return;
}

void LanguageFrame::showSelectedIcon(bool flag)
{
    selectedIconLabel->setVisible(flag);
}

bool LanguageFrame::isSelection()
{
    return selectedIconLabel->isVisible();
}

QToolButton* LanguageFrame::createToolBtn()
{
    QToolButton *btn = new QToolButton(this);
    btn->setAutoRaise(true);
    btn->setPopupMode(QToolButton::InstantPopup);
    QMenu *menu = new QMenu(btn);
    btn->setMenu(menu);
    QAction *edit = new QAction(btn);
    QAction *del = new QAction(btn);
    edit->setText(tr("Input Settings"));
    del->setText(tr("Delete"));
    menu->addAction(edit);
    menu->addAction(del);

    connect(menu, &QMenu::aboutToShow, [=](){
        if (selectedIconLabel->isVisible()) {
            del->setEnabled(false);
        } else {
            del->setEnabled(true);
        }
    });

    connect(del, &QAction::triggered, this, [=](){
        Q_EMIT deleted();
        this->deleteLater();
    });

    connect(edit, &QAction::triggered, this, [=](){
        QProcess process;
        process.startDetached("fcitx5-config-qt");

    });

    btn->setIcon(QIcon::fromTheme("view-more-horizontal-symbolic"));
    btn->setProperty("useButtonPalette", true);
    btn->setFixedWidth(36);
    return btn;
}

QString LanguageFrame::getShowName()
{
    return this->nameLabel->text();
}

void LanguageFrame::reloadIcon()
{
     selectedIconLabel->setPixmap(selectIcon.pixmap(selectIcon.actualSize(QSize(16, 16))));
}
